import { ListPage } from '../models/ListPage';
import { Searchable } from '../models/Searchable';
import { Sortable } from '../models/Sortable';
import { Filters } from '../models/Filters';
import { Buyer } from '../models/Buyer';
import { BuyerSupplier } from '../models/BuyerSupplier';
import { PartialDeep } from '../models/PartialDeep';
import { RequiredDeep } from '../models/RequiredDeep';
import { RequestOptions } from '../models/RequestOptions';
declare class Buyers {
    private impersonating;
    /**
    * @ignore
    * not part of public api, don't include in generated docs
    */
    constructor();
    /**
     * Get a list of buyers.
     * Check out the {@link https://ordercloud.io/api-reference/buyer/buyers/list|api docs} for more info
     *
     * @param listOptions.search Word or phrase to search for.
     * @param listOptions.searchOn Comma-delimited list of fields to search on.
     * @param listOptions.sortBy Comma-delimited list of fields to sort by.
     * @param listOptions.page Page of results to return. Default: 1. When paginating through many items (> page 30), we recommend the "Last ID" method, as outlined in the Advanced Querying documentation.
     * @param listOptions.pageSize Number of results to return per page. Default: 20, max: 100.
     * @param listOptions.filters An object or dictionary representing key/value pairs to apply as filters. Valid keys are top-level properties of the returned model or 'xp.???'
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    List<TBuyer extends Buyer>(listOptions?: {
        search?: string;
        searchOn?: Searchable<'Buyers.List'>;
        sortBy?: Sortable<'Buyers.List'>;
        page?: number;
        pageSize?: number;
        filters?: Filters;
    }, requestOptions?: RequestOptions): Promise<RequiredDeep<ListPage<TBuyer>>>;
    /**
     * Create a new buyer. If ID is provided and an object with that ID already exists, a 409 (conflict) error is returned.
     * Check out the {@link https://ordercloud.io/api-reference/buyer/buyers/create|api docs} for more info
     *
     * @param buyer Required fields: Name
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    Create<TBuyer extends Buyer>(buyer: Buyer, requestOptions?: RequestOptions): Promise<RequiredDeep<TBuyer>>;
    /**
     * Get a single buyer.
     * Check out the {@link https://ordercloud.io/api-reference/buyer/buyers/get|api docs} for more info
     *
     * @param buyerID ID of the buyer.
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    Get<TBuyer extends Buyer>(buyerID: string, requestOptions?: RequestOptions): Promise<RequiredDeep<TBuyer>>;
    /**
     * Create or update a buyer. If an object with the same ID already exists, it will be overwritten.
     * Check out the {@link https://ordercloud.io/api-reference/buyer/buyers/save|api docs} for more info
     *
     * @param buyerID ID of the buyer.
     * @param buyer Required fields: Name
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    Save<TBuyer extends Buyer>(buyerID: string, buyer: Buyer, requestOptions?: RequestOptions): Promise<RequiredDeep<TBuyer>>;
    /**
     * Delete a buyer.
     * Check out the {@link https://ordercloud.io/api-reference/buyer/buyers/delete|api docs} for more info
     *
     * @param buyerID ID of the buyer.
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    Delete(buyerID: string, requestOptions?: RequestOptions): Promise<void>;
    /**
     * Partially update a buyer.
     * Check out the {@link https://ordercloud.io/api-reference/buyer/buyers/patch|api docs} for more info
     *
     * @param buyerID ID of the buyer.
     * @param buyer
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    Patch<TBuyer extends Buyer>(buyerID: string, buyer: PartialDeep<Buyer>, requestOptions?: RequestOptions): Promise<RequiredDeep<TBuyer>>;
    /**
     * Get a list of buyer buyer sellers.
     * Check out the {@link https://ordercloud.io/api-reference/buyer/buyers/list-buyer-sellers|api docs} for more info
     *
     * @param buyerID ID of the buyer.
     * @param listOptions.search Word or phrase to search for.
     * @param listOptions.searchOn Comma-delimited list of fields to search on.
     * @param listOptions.sortBy Comma-delimited list of fields to sort by.
     * @param listOptions.page Page of results to return. Default: 1. When paginating through many items (> page 30), we recommend the "Last ID" method, as outlined in the Advanced Querying documentation.
     * @param listOptions.pageSize Number of results to return per page. Default: 20, max: 100.
     * @param listOptions.filters An object or dictionary representing key/value pairs to apply as filters. Valid keys are top-level properties of the returned model or 'xp.???'
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    ListBuyerSellers<TBuyerSupplier extends BuyerSupplier>(buyerID: string, listOptions?: {
        search?: string;
        searchOn?: Searchable<'Buyers.ListBuyerSellers'>;
        sortBy?: Sortable<'Buyers.ListBuyerSellers'>;
        page?: number;
        pageSize?: number;
        filters?: Filters;
    }, requestOptions?: RequestOptions): Promise<RequiredDeep<ListPage<TBuyerSupplier>>>;
    /**
     * @description
     * enables impersonation by calling the subsequent method with the stored impersonation token
     *
     * @example
     * Buyers.As().List() // lists Buyers using the impersonated users' token
     */
    As(): this;
}
declare const _default: Buyers;
export default _default;
