import { ListPage } from '../models/ListPage';
import { Searchable } from '../models/Searchable';
import { Sortable } from '../models/Sortable';
import { Filters } from '../models/Filters';
import { IntegrationEvent } from '../models/IntegrationEvent';
import { OrderWorksheet } from '../models/OrderWorksheet';
import { OrderDirection } from '../models/OrderDirection';
import { OrderShipMethodSelection } from '../models/OrderShipMethodSelection';
import { PartialDeep } from '../models/PartialDeep';
import { RequiredDeep } from '../models/RequiredDeep';
import { RequestOptions } from '../models/RequestOptions';
declare class IntegrationEvents {
    private impersonating;
    /**
    * @ignore
    * not part of public api, don't include in generated docs
    */
    constructor();
    /**
     * Get a list of integration events.
     * Check out the {@link https://ordercloud.io/api-reference/integrations/integration-events/list|api docs} for more info
     *
     * @param listOptions.search Word or phrase to search for.
     * @param listOptions.searchOn Comma-delimited list of fields to search on.
     * @param listOptions.sortBy Comma-delimited list of fields to sort by.
     * @param listOptions.page Page of results to return. Default: 1. When paginating through many items (> page 30), we recommend the "Last ID" method, as outlined in the Advanced Querying documentation.
     * @param listOptions.pageSize Number of results to return per page. Default: 20, max: 100.
     * @param listOptions.filters An object or dictionary representing key/value pairs to apply as filters. Valid keys are top-level properties of the returned model or 'xp.???'
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    List<TIntegrationEvent extends IntegrationEvent>(listOptions?: {
        search?: string;
        searchOn?: Searchable<'IntegrationEvents.List'>;
        sortBy?: Sortable<'IntegrationEvents.List'>;
        page?: number;
        pageSize?: number;
        filters?: Filters;
    }, requestOptions?: RequestOptions): Promise<RequiredDeep<ListPage<TIntegrationEvent>>>;
    /**
     * Create a new integration event. If ID is provided and an object with that ID already exists, a 409 (conflict) error is returned.
     * Check out the {@link https://ordercloud.io/api-reference/integrations/integration-events/create|api docs} for more info
     *
     * @param integrationEvent Required fields: CustomImplementationUrl, Name, HashKey
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    Create<TIntegrationEvent extends IntegrationEvent>(integrationEvent: IntegrationEvent, requestOptions?: RequestOptions): Promise<RequiredDeep<TIntegrationEvent>>;
    /**
     * Get a single integration event.
     * Check out the {@link https://ordercloud.io/api-reference/integrations/integration-events/get|api docs} for more info
     *
     * @param integrationEventID ID of the integration event.
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    Get<TIntegrationEvent extends IntegrationEvent>(integrationEventID: string, requestOptions?: RequestOptions): Promise<RequiredDeep<TIntegrationEvent>>;
    /**
     * Create or update an integration event. If an object with the same ID already exists, it will be overwritten.
     * Check out the {@link https://ordercloud.io/api-reference/integrations/integration-events/save|api docs} for more info
     *
     * @param integrationEventID ID of the integration event.
     * @param integrationEvent Required fields: CustomImplementationUrl, Name, HashKey
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    Save<TIntegrationEvent extends IntegrationEvent>(integrationEventID: string, integrationEvent: IntegrationEvent, requestOptions?: RequestOptions): Promise<RequiredDeep<TIntegrationEvent>>;
    /**
     * Delete an integration event.
     * Check out the {@link https://ordercloud.io/api-reference/integrations/integration-events/delete|api docs} for more info
     *
     * @param integrationEventID ID of the integration event.
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    Delete(integrationEventID: string, requestOptions?: RequestOptions): Promise<void>;
    /**
     * Partially update an integration event.
     * Check out the {@link https://ordercloud.io/api-reference/integrations/integration-events/patch|api docs} for more info
     *
     * @param integrationEventID ID of the integration event.
     * @param integrationEvent
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    Patch<TIntegrationEvent extends IntegrationEvent>(integrationEventID: string, integrationEvent: PartialDeep<IntegrationEvent>, requestOptions?: RequestOptions): Promise<RequiredDeep<TIntegrationEvent>>;
    /**
     * Calculate an order.
     * Check out the {@link https://ordercloud.io/api-reference/integrations/integration-events/calculate|api docs} for more info
     *
     * @param direction Direction of the order, from the current user's perspective. Possible values: incoming, outgoing, all.
     * @param orderID ID of the order.
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    Calculate<TOrderWorksheet extends OrderWorksheet>(direction: OrderDirection, orderID: string, requestOptions?: RequestOptions): Promise<RequiredDeep<TOrderWorksheet>>;
    /**
     * Estimate shipping cost.
     * Check out the {@link https://ordercloud.io/api-reference/integrations/integration-events/estimate-shipping|api docs} for more info
     *
     * @param direction Direction of the order, from the current user's perspective. Possible values: incoming, outgoing, all.
     * @param orderID ID of the order.
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    EstimateShipping<TOrderWorksheet extends OrderWorksheet>(direction: OrderDirection, orderID: string, requestOptions?: RequestOptions): Promise<RequiredDeep<TOrderWorksheet>>;
    /**
     * Select a ship method.
     * Check out the {@link https://ordercloud.io/api-reference/integrations/integration-events/select-shipmethods|api docs} for more info
     *
     * @param direction Direction of the order, from the current user's perspective. Possible values: incoming, outgoing, all.
     * @param orderID ID of the order.
     * @param orderShipMethodSelection
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    SelectShipmethods<TOrderWorksheet extends OrderWorksheet>(direction: OrderDirection, orderID: string, orderShipMethodSelection: OrderShipMethodSelection, requestOptions?: RequestOptions): Promise<RequiredDeep<TOrderWorksheet>>;
    /**
     * Get a single order worksheet.
     * Check out the {@link https://ordercloud.io/api-reference/integrations/integration-events/get-worksheet|api docs} for more info
     *
     * @param direction Direction of the order, from the current user's perspective. Possible values: incoming, outgoing, all.
     * @param orderID ID of the order.
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    GetWorksheet<TOrderWorksheet extends OrderWorksheet>(direction: OrderDirection, orderID: string, requestOptions?: RequestOptions): Promise<RequiredDeep<TOrderWorksheet>>;
    /**
     * @description
     * enables impersonation by calling the subsequent method with the stored impersonation token
     *
     * @example
     * IntegrationEvents.As().List() // lists IntegrationEvents using the impersonated users' token
     */
    As(): this;
}
declare const _default: IntegrationEvents;
export default _default;
