import { ListPage } from '../models/ListPage';
import { Searchable } from '../models/Searchable';
import { Sortable } from '../models/Sortable';
import { Filters } from '../models/Filters';
import { SellerApprovalRule } from '../models/SellerApprovalRule';
import { PartialDeep } from '../models/PartialDeep';
import { RequiredDeep } from '../models/RequiredDeep';
import { RequestOptions } from '../models/RequestOptions';
declare class SellerApprovalRules {
    private impersonating;
    /**
    * @ignore
    * not part of public api, don't include in generated docs
    */
    constructor();
    /**
     * Get a list of seller approval rules.
     * Check out the {@link https://ordercloud.io/api-reference/orders-and-fulfillment/seller-approval-rules/list|api docs} for more info
     *
     * @param listOptions.search Word or phrase to search for.
     * @param listOptions.searchOn Comma-delimited list of fields to search on.
     * @param listOptions.sortBy Comma-delimited list of fields to sort by.
     * @param listOptions.page Page of results to return. Default: 1. When paginating through many items (> page 30), we recommend the "Last ID" method, as outlined in the Advanced Querying documentation.
     * @param listOptions.pageSize Number of results to return per page. Default: 20, max: 100.
     * @param listOptions.filters An object or dictionary representing key/value pairs to apply as filters. Valid keys are top-level properties of the returned model or 'xp.???'
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    List<TSellerApprovalRule extends SellerApprovalRule>(listOptions?: {
        search?: string;
        searchOn?: Searchable<'SellerApprovalRules.List'>;
        sortBy?: Sortable<'SellerApprovalRules.List'>;
        page?: number;
        pageSize?: number;
        filters?: Filters;
    }, requestOptions?: RequestOptions): Promise<RequiredDeep<ListPage<TSellerApprovalRule>>>;
    /**
     * Create a new seller approval rule. If ID is provided and an object with that ID already exists, a 409 (conflict) error is returned.
     * Check out the {@link https://ordercloud.io/api-reference/orders-and-fulfillment/seller-approval-rules/create|api docs} for more info
     *
     * @param sellerApprovalRule Required fields: ApprovalType, ApprovingGroupID, RuleExpression
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    Create<TSellerApprovalRule extends SellerApprovalRule>(sellerApprovalRule: SellerApprovalRule, requestOptions?: RequestOptions): Promise<RequiredDeep<TSellerApprovalRule>>;
    /**
     * Get a single seller approval rule.
     * Check out the {@link https://ordercloud.io/api-reference/orders-and-fulfillment/seller-approval-rules/get|api docs} for more info
     *
     * @param approvalRuleID ID of the approval rule.
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    Get<TSellerApprovalRule extends SellerApprovalRule>(approvalRuleID: string, requestOptions?: RequestOptions): Promise<RequiredDeep<TSellerApprovalRule>>;
    /**
     * Create or update a seller approval rule. If an object with the same ID already exists, it will be overwritten.
     * Check out the {@link https://ordercloud.io/api-reference/orders-and-fulfillment/seller-approval-rules/save|api docs} for more info
     *
     * @param approvalRuleID ID of the approval rule.
     * @param sellerApprovalRule Required fields: ApprovalType, ApprovingGroupID, RuleExpression
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    Save<TSellerApprovalRule extends SellerApprovalRule>(approvalRuleID: string, sellerApprovalRule: SellerApprovalRule, requestOptions?: RequestOptions): Promise<RequiredDeep<TSellerApprovalRule>>;
    /**
     * Delete a seller approval rule.
     * Check out the {@link https://ordercloud.io/api-reference/orders-and-fulfillment/seller-approval-rules/delete|api docs} for more info
     *
     * @param approvalRuleID ID of the approval rule.
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    Delete(approvalRuleID: string, requestOptions?: RequestOptions): Promise<void>;
    /**
     * Partially update a seller approval rule.
     * Check out the {@link https://ordercloud.io/api-reference/orders-and-fulfillment/seller-approval-rules/patch|api docs} for more info
     *
     * @param approvalRuleID ID of the approval rule.
     * @param sellerApprovalRule
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    Patch<TSellerApprovalRule extends SellerApprovalRule>(approvalRuleID: string, sellerApprovalRule: PartialDeep<SellerApprovalRule>, requestOptions?: RequestOptions): Promise<RequiredDeep<TSellerApprovalRule>>;
    /**
     * @description
     * enables impersonation by calling the subsequent method with the stored impersonation token
     *
     * @example
     * SellerApprovalRules.As().List() // lists SellerApprovalRules using the impersonated users' token
     */
    As(): this;
}
declare const _default: SellerApprovalRules;
export default _default;
