import { ListPage } from '../models/ListPage';
import { Searchable } from '../models/Searchable';
import { Sortable } from '../models/Sortable';
import { Filters } from '../models/Filters';
import { Subscription } from '../models/Subscription';
import { PartialDeep } from '../models/PartialDeep';
import { RequiredDeep } from '../models/RequiredDeep';
import { RequestOptions } from '../models/RequestOptions';
declare class Subscriptions {
    private impersonating;
    /**
    * @ignore
    * not part of public api, don't include in generated docs
    */
    constructor();
    /**
     * Get a list of subscriptions.
     * Check out the {@link https://ordercloud.io/api-reference/orders-and-fulfillment/subscriptions/list|api docs} for more info
     *
     * @param listOptions.search Word or phrase to search for.
     * @param listOptions.searchOn Comma-delimited list of fields to search on.
     * @param listOptions.sortBy Comma-delimited list of fields to sort by.
     * @param listOptions.page Page of results to return. Default: 1. When paginating through many items (> page 30), we recommend the "Last ID" method, as outlined in the Advanced Querying documentation.
     * @param listOptions.pageSize Number of results to return per page. Default: 20, max: 100.
     * @param listOptions.filters An object or dictionary representing key/value pairs to apply as filters. Valid keys are top-level properties of the returned model or 'xp.???'
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    List<TSubscription extends Subscription>(listOptions?: {
        search?: string;
        searchOn?: Searchable<'Subscriptions.List'>;
        sortBy?: Sortable<'Subscriptions.List'>;
        page?: number;
        pageSize?: number;
        filters?: Filters;
    }, requestOptions?: RequestOptions): Promise<RequiredDeep<ListPage<TSubscription>>>;
    /**
     * Create a new subscription. If ID is provided and an object with that ID already exists, a 409 (conflict) error is returned.
     * Check out the {@link https://ordercloud.io/api-reference/orders-and-fulfillment/subscriptions/create|api docs} for more info
     *
     * @param subscription Required fields: Frequency, Interval, NextOrderDate
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    Create<TSubscription extends Subscription>(subscription: Subscription, requestOptions?: RequestOptions): Promise<RequiredDeep<TSubscription>>;
    /**
     * Get a single subscription.
     * Check out the {@link https://ordercloud.io/api-reference/orders-and-fulfillment/subscriptions/get|api docs} for more info
     *
     * @param subscriptionID ID of the subscription.
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    Get<TSubscription extends Subscription>(subscriptionID: string, requestOptions?: RequestOptions): Promise<RequiredDeep<TSubscription>>;
    /**
     * Create or update a subscription. If an object with the same ID already exists, it will be overwritten.
     * Check out the {@link https://ordercloud.io/api-reference/orders-and-fulfillment/subscriptions/save|api docs} for more info
     *
     * @param subscriptionID ID of the subscription.
     * @param subscription Required fields: Frequency, Interval, NextOrderDate
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    Save<TSubscription extends Subscription>(subscriptionID: string, subscription: Subscription, requestOptions?: RequestOptions): Promise<RequiredDeep<TSubscription>>;
    /**
     * Delete a subscription.
     * Check out the {@link https://ordercloud.io/api-reference/orders-and-fulfillment/subscriptions/delete|api docs} for more info
     *
     * @param subscriptionID ID of the subscription.
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    Delete(subscriptionID: string, requestOptions?: RequestOptions): Promise<void>;
    /**
     * Partially update a subscription.
     * Check out the {@link https://ordercloud.io/api-reference/orders-and-fulfillment/subscriptions/patch|api docs} for more info
     *
     * @param subscriptionID ID of the subscription.
     * @param subscription
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    Patch<TSubscription extends Subscription>(subscriptionID: string, subscription: PartialDeep<Subscription>, requestOptions?: RequestOptions): Promise<RequiredDeep<TSubscription>>;
    /**
     * @description
     * enables impersonation by calling the subsequent method with the stored impersonation token
     *
     * @example
     * Subscriptions.As().List() // lists Subscriptions using the impersonated users' token
     */
    As(): this;
}
declare const _default: Subscriptions;
export default _default;
